@@ -1,4 +1,4 @@
 """
 Support for setting up and defining assistants that you can use in Kodexa
 """
-from .assistant import Assistant, AssistantContext
+from .assistant import Assistant, AssistantContext, AssistantResponse
