@@ -61,6 +61,58 @@ class LocalDocumentStore(DocumentStore):
         """ """
         return "Local Document Store"
 
+    def put_native(self, path: str, content: Any, force_replace=False):
+        """
+
+        Args:
+          path (str): The path to the native file
+          content (Any): The content to store
+        Returns:
+
+        """
+
+        # In order to store a native document we will first get the family
+        # then we will create a content object for the native object
+        # and also a content object for the document that references it
+
+        family = self.get_family_by_path(path)
+
+        if family is None:
+            family = DocumentFamily(path, self.get_ref())
+            self.metastore.append(family)
+
+        from kodexa.model import ContentType
+        native_content_object = ContentObject(content_type=ContentType.NATIVE)
+        family.content_objects.append(native_content_object)
+        with open(os.path.join(self.store_path, native_content_object.id), 'wb') as file:
+            file.write(content)
+
+        document = Document()
+        document.source.connector = "document-store"
+        document.source.headers = {"ref": family.store_ref, "family": family.id, "id": native_content_object.id}
+        content_event = family.add_document(document)
+        document.to_kdxa(os.path.join(self.store_path, content_event.content_object.id) + ".kdxa")
+
+    def get_source_by_content_object(self, document_family: DocumentFamily, content_object: ContentObject) -> \
+            Any:
+        """
+        Get the source for a given content object
+
+        Args:
+          document_family (DocumentFamily): the document family
+          content_object  (ContentObject): the content object
+
+        Returns:
+          the source (or None if not found)
+
+        """
+        self.read_metastore()
+        family = self.get_family(document_family.id)
+        if family is None:
+            return None
+
+        return open(os.path.join(self.store_path, content_object.id), 'rb')
+
     def __iter__(self):
         self.index = 0
         return self
@@ -92,7 +144,7 @@ class LocalDocumentStore(DocumentStore):
             if document.source.original_filename is not None:
                 self.put(document.source.original_filename, document)
 
-    def get_ref(self) -> str:
+    def get_ref(self) -> 'str':
         """ """
         return self.store_path
 
@@ -153,13 +205,13 @@ class LocalDocumentStore(DocumentStore):
         with open(os.path.join(self.store_path, 'metastore.json'), 'w') as f:
             f.write(jsonpickle.encode(self.metastore))
 
-    def get_family(self, document_family_id: str) -> Optional[DocumentFamily]:
+    def get_family(self, document_family_id: str) -> 'Optional[DocumentFamily]':
         for family in self.metastore:
             if family.id == document_family_id:
                 return family
         return None
 
-    def get_by_uuid(self, uuid: str) -> Optional[Document]:
+    def get_by_uuid(self, uuid: str) -> 'Optional[Document]':
         """
 
         Args:
@@ -175,7 +227,7 @@ class LocalDocumentStore(DocumentStore):
                     return Document.from_kdxa(os.path.join(self.store_path, content_object.id) + ".kdxa")
         return None
 
-    def get_by_path(self, path: str) -> Optional[Document]:
+    def get_by_path(self, path: str) -> 'Optional[Document]':
         """Return the latest document in the family at the given path
 
         Args:
@@ -187,17 +239,15 @@ class LocalDocumentStore(DocumentStore):
         """
         for family in self.metastore:
             if family.path == path:
-                # TODO we need to get the latest document from the family
-
                 return Document.from_kdxa(os.path.join(self.store_path, family.get_latest_content().id) + ".kdxa")
         return None
 
-    def query_families(self, query: str = "*", page: int = 1, page_size: int = 100) -> List[DocumentFamily]:
+    def query_families(self, query: str = "*", page: int = 1, page_size: int = 100) -> 'List[DocumentFamily]':
 
         # TODO implement query
         return self.metastore
 
-    def get_family_by_path(self, path: str) -> Optional[DocumentFamily]:
+    def get_family_by_path(self, path: str) -> 'Optional[DocumentFamily]':
         """
 
         Args:
@@ -211,7 +261,7 @@ class LocalDocumentStore(DocumentStore):
                 return family
         return None
 
-    def get_latest_document(self, path: str) -> Optional[Document]:
+    def get_latest_document(self, path: str) -> 'Optional[Document]':
         """
 
         Args:
@@ -225,7 +275,7 @@ class LocalDocumentStore(DocumentStore):
                 return self.get_document_by_content_object(family, family.content_objects[-1])
         return None
 
-    def list_objects(self) -> List[ContentObject]:
+    def list_objects(self) -> 'List[ContentObject]':
         """ """
         co_list: List[ContentObject] = []
         for family in self.metastore:
@@ -233,7 +283,7 @@ class LocalDocumentStore(DocumentStore):
 
         return co_list
 
-    def count(self) -> int:
+    def count(self) -> 'int':
         """Returns a count of the number of document families
 
         :return:
@@ -277,7 +327,7 @@ class LocalDocumentStore(DocumentStore):
                 self.write_metastore()
 
     def get_document_by_content_object(self, document_family: DocumentFamily,
-                                       content_object: ContentObject) -> Document:
+                                       content_object: ContentObject) -> 'Document':
         """
 
         Args:
@@ -290,7 +340,21 @@ class LocalDocumentStore(DocumentStore):
         """
         return Document.from_kdxa(os.path.join(self.store_path, content_object.id) + ".kdxa")
 
-    def put(self, path: str, document: Document, force_replace: bool = False) -> DocumentFamily:
+    def replace_content_object(self, document_family: DocumentFamily, content_object_id: str,
+                               document: Document) -> 'Optional[DocumentFamily]':
+
+        for co in document_family.content_objects:
+            if co.id == content_object_id:
+                document.to_kdxa(os.path.join(self.store_path, content_object_id) + ".kdxa")
+                co.labels = document.labels
+                co.classes = document.classes
+                self.write_metastore()
+                return document_family
+
+        return None
+
+
+    def put(self, path: str, document: Document, force_replace: bool = False) -> 'DocumentFamily':
         """
 
         Args:
@@ -377,7 +441,7 @@ class LocalModelStore(ModelStore):
         else:
             return None
 
-    def put_native(self, path: str, content: Any):
+    def put_native(self, path: str, content: Any, force_replace=False):
         """
 
         Args:
